@@ -1,6 +1,7 @@
 from typing import Dict
-
 import platform
+import subprocess
+
 import psutil
 
 
@@ -31,3 +32,14 @@ def call_attribute_if_available(object_name, attribute_name):
     if hasattr(object_name, attribute_name):
         return getattr(object_name, attribute_name)()
     return None
+
+
+def get_win_version() -> str:
+    """Windows only utility which returns the current Windows version."""
+    output = subprocess.getoutput("ver")
+    # Windows terminal `ver` command is bugged, until that's fixed, check by build
+    #  number. (the same applies for `platform.version()`)
+    if int(output.split(".")[2]) >= 22000:
+        return "11"  # Windows 11
+
+    return "10"  # Windows 10 (or lower)
